package com.goldenwater.yjjt.mapper;

import com.goldenwater.yjjt.domain.YjjtDailyStatistics;
import com.goldenwater.yjjt.domain.YjjtStatisticsDTO;
import com.goldenwater.yjjt.domain.YjjtYearlyDataStatistics;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

@Mapper
public interface YjjtStatisticsMapper {

    List<YjjtDailyStatistics> selectDailyStatistics();

    List<YjjtDailyStatistics> selectWeeklyStatistics();

    List<YjjtDailyStatistics> selectMonthlyStatistics();

    List<YjjtYearlyDataStatistics> selectYearlyStatisticsData(@Param("year") String year);

    List<YjjtYearlyDataStatistics> selectYearlySlStatisticsData(@Param("year") String year);

    List<YjjtYearlyDataStatistics> selectYearlySzStatisticsData(@Param("year") String year);

    List<YjjtStatisticsDTO> selectUnitYearlyStatistics(@Param("unitCode") String unitCode);

    List<YjjtStatisticsDTO> selectStationCountByYear(@Param("unitCode") String unitCode);

    int selectTodayDataCount(@Param("unitCode") String unitCode);

    int selectWeekDataCount(@Param("unitCode") String unitCode);

    int selectMonthDataCount(@Param("unitCode") String unitCode);
}
